@@ -2,7 +2,7 @@
 //
 // pgAgent - PostgreSQL Tools
 //
-// Copyright (C) 2002 - 2012, The pgAdmin Development Team
+// Copyright (C) 2002 - 2014, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
 // pgAgent.h - main include
@@ -54,7 +54,7 @@ void MainLoop();
 #ifdef __WIN32__
 #include <windows.h>
 void CheckForInterrupt();
-HANDLE win32_popen_r(const TCHAR *command);
+HANDLE win32_popen_r(const TCHAR *command, HANDLE &handle);
 #endif
 
 #endif // PGAGENT_H
