@@ -2,7 +2,7 @@
 //
 // pgAgent - PostgreSQL Tools
 //
-// Copyright (C) 2002 - 2012 The pgAdmin Development Team
+// Copyright (C) 2002 - 2014 The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
 // job.cpp - pgAgent job
@@ -80,6 +80,7 @@ Job::~Job()
 int Job::Execute()
 {
 	int rc = 0;
+	bool succeeded = false;
 	DBresult *steps = threadConn->Execute(
 	                      wxT("SELECT * ")
 	                      wxT("  FROM pgagent.pga_jobstep ")
@@ -138,13 +139,14 @@ int Job::Execute()
 				{
 					LogMessage(wxString::Format(_("Executing SQL step %s (part of job %s)"), stepid.c_str(), jobid.c_str()), LOG_DEBUG);
 					rc = stepConn->ExecuteVoid(steps->GetString(wxT("jstcode")));
+					succeeded = stepConn->LastCommandOk();
 					output = stepConn->GetLastError();
 					stepConn->Return();
 				}
 				else
 				{
 					output = _("Couldn't get a connection to the database!");
-					rc = -1;
+					succeeded = false;
 				}
 
 
@@ -234,15 +236,16 @@ int Job::Execute()
 				// Execute the file and capture the output
 #ifdef __WIN32__
 				// The Windows way
-				HANDLE h_script;
+				HANDLE h_script, h_process;
 				DWORD dwRead;
 				char chBuf[4098];
 
-				h_script = win32_popen_r(filename.wc_str());
+				h_script = win32_popen_r(filename.wc_str(), h_process);
 				if (!h_script)
 				{
 					output.Printf(_("Couldn't execute script: %s, GetLastError() returned %d, errno = %d"), filename.c_str(), GetLastError(), errno);
 					LogMessage(output, LOG_WARNING);
+					CloseHandle(h_process);
 					rc = -1;
 					break;
 				}
@@ -262,8 +265,9 @@ int Job::Execute()
 				}
 
 
+				GetExitCodeProcess(h_process, (LPDWORD)&rc);
+				CloseHandle(h_process);
 				CloseHandle(h_script);
-				rc = 1;
 
 #else
 				// The *nix way.
@@ -292,8 +296,14 @@ int Job::Execute()
 					rc = WEXITSTATUS(rc);
 				else
 					rc = -1;
+
 #endif
 
+				// set success status for batch runs, be pessimistic by default
+				LogMessage(wxString::Format(_("Script return code: %d"), rc), LOG_DEBUG);
+				if (rc == 0)
+					succeeded = true;
+
 				// Delete the file/directory. If we fail, don't overwrite the script output in the log, just throw warnings.
 				if (!wxRemoveFile(filename))
 				{
@@ -319,7 +329,7 @@ int Job::Execute()
 		}
 
 		wxString stepstatus;
-		if (rc == 0)
+		if (succeeded)
 			stepstatus = wxT("s");
 		else
 			stepstatus = steps->GetString(wxT("jstonerror"));
